@@ -2,16 +2,19 @@ from .request import Request
 
 
 URL = "https://www.anilibria.tv/public"
+__all__ = ["PublicRequest"]
 
 
 class PublicRequest:
+    """
+    Представляет собой запросы на сайт "https://www.anilibria.tv/public"
+    Здесь не будут реализованы методы для "/api", так как существует v2, в котором точно такие же запросы,
+    и к тому же документация к "/api" не обновлялась более двух лет.
+    """
+
     request: Request
 
     def __init__(self, request: Request) -> None:
-        """
-
-        :param request:
-        """
         self.request: Request = request
 
     async def login(self, mail: str, password: str) -> dict:
@@ -23,8 +26,3 @@ class PublicRequest:
         """
         payload: dict = {"mail": mail, "passwd": password}
         return await self.request.request("POST", f"{URL}/login.php", data=payload)
-
-    # * В документации расписаны публичные методы, но им более 2х лет, и я не смог заставить их работать
-    # * code: 400 Message: Unknown query
-    # * В исходном коде сайта расписаны некоторые методы, но документацию на них не завезли.
-    # * Поэтому они не будут реализованы.
