@@ -1,28 +1,32 @@
-from dataclasses import dataclass, field
 from typing import List, Optional
 
+from attrs import define, field
+
 from .title import Title
+from ..attrs_utils import convert_list
 
 
-@dataclass(slots=True)
+__all__ = ["Schedule", "YouTubeData", "SeedStats"]
+
+
+@define
 class Schedule:
     day: Optional[int] = field(default=None)
-    list: Optional[List[Title]] = field(default_factory=list)
-
-    def __post_init__(self):
-        self.list = [Title(**title) for title in self.list]
+    list: Optional[List[Title]] = field(converter=convert_list(Title), factory=list)
 
 
-@dataclass(slots=True, frozen=True)
+@define
 class YouTubeData:
     id: Optional[int] = field(default=None)
     title: Optional[str] = field(default=None)
     image: Optional[str] = field(default=None)
     youtube_id: Optional[str] = field(default=None)
     timestamp: Optional[int] = field(default=None)
+    comments: Optional[int] = field(default=None)
+    views: Optional[int] = field(default=None)
 
 
-@dataclass(slots=True, frozen=True)
+@define
 class SeedStats:
     downloaded: Optional[int] = field(default=None)
     uploaded: Optional[int] = field(default=None)
