@@ -57,6 +57,10 @@ class Poster(DictSerializer):
     url: Optional[str] = field(default=None)
     raw_base64_file: Optional[str] = field(default=None)
 
+    @property
+    def full_url(self):
+        return f"https://anilibria.tv{self.url}"
+
 
 @define()
 class Posters(DictSerializer):
@@ -173,7 +177,9 @@ class Player(DictSerializer):
     alternative_player: Optional[str] = field(default=None)
     host: Optional[str] = field(default=None)
     series: Optional[Series] = field(converter=convert(Series), default=None)
-    playlist: Optional[Union[List[Serie], Dict[str, Serie]]] = field(converter=convert_playlist(Serie), factory=list)
+    playlist: Optional[Union[List[Serie], Dict[str, Serie]]] = field(
+        converter=convert_playlist(Serie), factory=list
+    )
 
 
 @define()
